@@ -45,7 +45,7 @@ boolean fill_input_buffer(j_decompress_ptr cinfo) {
     jpeg_source_adaptor* adaptor = reinterpret_cast<jpeg_source_adaptor*>(cinfo->src);
     adaptor->mgr.next_input_byte = adaptor->buf;
     adaptor->mgr.bytes_in_buffer = adaptor->s->read(adaptor->buf, buffer_size);
-    return true;
+    return (boolean) true;
 }
 
 void skip_input_data(j_decompress_ptr cinfo, long num_bytes) {
